@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: CJKFont.pm,v 1.5 2004/06/07 19:44:36 fredo Exp $
+#   $Id: CJKFont.pm,v 1.6 2004/06/15 09:14:42 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont::CJKFont;
@@ -50,7 +50,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::CIDFont );
 
-    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/07 19:44:36 $
+    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:14:42 $
 
     $fonts = { };
     $cmap = { };
@@ -226,6 +226,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: CJKFont.pm,v $
+    Revision 1.6  2004/06/15 09:14:42  fredo
+    removed cr+lf
+
     Revision 1.5  2004/06/07 19:44:36  fredo
     cleaned out cr+lf for lf
 
